pub enum InputType {
Show 47 variants
InsertText,
InsertReplacementText,
InsertLineBreak,
InsertParagraph,
InsertOrderedList,
InsertUnorderedList,
InsertHorizontalRule,
InsertFromYank,
InsertFromDrop,
InsertFromPaste,
InsertFromPasteAsQuotation,
InsertTranspose,
InsertCompositionText,
InsertLink,
DeleteWordBackward,
DeleteWordForward,
DeleteSoftLineBackward,
DeleteSoftLineForward,
DeleteEntireSoftLine,
DeleteHardLineBackward,
DeleteHardLineForward,
DeleteByDrag,
DeleteByCut,
DeleteContent,
DeleteContentBackward,
DeleteContentForward,
HistoryUndo,
HistoryRedo,
FormatBold,
FormatItalic,
FormatUnderline,
FormatStrikeThrough,
FormatSuperscript,
FormatSubscript,
FormatJustifyFull,
FormatJustifyCenter,
FormatJustifyRight,
FormatJustifyLeft,
FormatIndent,
FormatOutdent,
FormatRemove,
FormatSetBlockTextDirection,
FormatSetInlineTextDirection,
FormatBackColor,
FormatFontColor,
FormatFontName,
Unknown(String),
}Available on crate feature
prelude only.Expand description
The kind of mutation that is about to be applied to an editable element.
These map to the inputType attribute of the underlying DOM InputEvent. The
full list of values is defined in the W3C Input Events spec at
https://w3c.github.io/input-events/#interface-InputEvent-Attributes. Any value
not covered by a known variant (e.g. one introduced by a newer user agent) is
preserved verbatim in InputType::Unknown.
Variants
InsertText
InsertReplacementText
InsertLineBreak
InsertParagraph
InsertOrderedList
InsertUnorderedList
InsertHorizontalRule
InsertFromYank
InsertFromDrop
InsertFromPaste
InsertFromPasteAsQuotation
InsertTranspose
InsertCompositionText
InsertLink
DeleteWordBackward
DeleteWordForward
DeleteSoftLineBackward
DeleteSoftLineForward
DeleteEntireSoftLine
DeleteHardLineBackward
DeleteHardLineForward
DeleteByDrag
DeleteByCut
DeleteContent
DeleteContentBackward
DeleteContentForward
HistoryUndo
HistoryRedo
FormatBold
FormatItalic
FormatUnderline
FormatStrikeThrough
FormatSuperscript
FormatSubscript
FormatJustifyFull
FormatJustifyCenter
FormatJustifyRight
FormatJustifyLeft
FormatIndent
FormatOutdent
FormatRemove
FormatSetBlockTextDirection
FormatSetInlineTextDirection
FormatBackColor
FormatFontColor
FormatFontName
Unknown(String)
An inputType value not covered by the known variants, preserved as-is.
Implementations