#[non_exhaustive]#[repr(C, u8)]pub enum SymbolData {
Asset(BundledAsset),
AndroidArtifact(AndroidArtifactMetadata),
SwiftPackage(SwiftPackageMetadata),
}Available on crate feature
prelude only.Expand description
Unified symbol data that can represent both assets and permissions
This enum is used to serialize different types of metadata into the binary
using the same __ASSETS__ symbol prefix. The CBOR format allows for
self-describing data, making it easy to add new variants in the future.
Variant order does NOT matter for CBOR enum serialization - variants are matched by name (string), not by position or tag value.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Asset(BundledAsset)
An asset that should be bundled with the application
AndroidArtifact(AndroidArtifactMetadata)
Android plugin metadata (prebuilt artifacts + Gradle deps)
SwiftPackage(SwiftPackageMetadata)
Swift package metadata (SPM location + product)