pub struct FormData { /* private fields */ }Available on crate feature
prelude only.Implementations
Sourceimpl FormData
impl FormData
Sourcepub fn new(event: impl HasFormData + 'static) -> FormData
pub fn new(event: impl HasFormData + 'static) -> FormData
Create a new form event
Sourcepub fn parsed<T>(&self) -> Result<T, <T as FromStr>::Err>where
T: FromStr,
pub fn parsed<T>(&self) -> Result<T, <T as FromStr>::Err>where
T: FromStr,
Get the value of the form event as a parsed type
Sourcepub fn checked(&self) -> bool
pub fn checked(&self) -> bool
Try to parse the value as a boolean
Returns false if the value is not a boolean, or if it is false! Does not verify anything about the event itself, use with caution
Sourcepub fn values(&self) -> Vec<(String, FormValue)>
pub fn values(&self) -> Vec<(String, FormValue)>
Collect all the named form values from the containing form.
Every input must be named!
Sourcepub fn get_first(&self, name: &str) -> Option<FormValue>
pub fn get_first(&self, name: &str) -> Option<FormValue>
Get the first value with the given name