pub struct Global<T, R = T> { /* private fields */ }prelude only.Expand description
A lazy value that is created once per application and can be accessed from anywhere in that application
Implementations
Sourceimpl<T, R> Global<T, R>
impl<T, R> Global<T, R>
Sourceimpl<T, R> Global<T, R>where
T: Clone + InitializeFromFunction<R>,
impl<T, R> Global<T, R>where
T: Clone + InitializeFromFunction<R>,
Sourcepub const fn with_name(
constructor: fn() -> R,
key: &'static str,
) -> Global<T, R>
pub const fn with_name( constructor: fn() -> R, key: &'static str, ) -> Global<T, R>
Create this global signal with a specific key. This is useful for ensuring that the signal is unique across the application and accessible from outside the application too.
Sourcepub const fn with_location(
constructor: fn() -> R,
file: &'static str,
line: u32,
column: u32,
index: usize,
) -> Global<T, R>
pub const fn with_location( constructor: fn() -> R, file: &'static str, line: u32, column: u32, index: usize, ) -> Global<T, R>
Create this global signal with a specific key. This is useful for ensuring that the signal is unique across the application and accessible from outside the application too.
Sourcepub fn resolve(&self) -> Twhere
T: 'static,
pub fn resolve(&self) -> Twhere
T: 'static,
Resolve the global value. This will try to get the existing value from the current virtual dom, and if it doesn’t exist, it will create a new one.
Sourcepub fn origin_scope(&self) -> ScopeId
pub fn origin_scope(&self) -> ScopeId
Get the scope the signal was created in.