pub struct SerializedDragData {
pub mouse: SerializedPointInteraction,
pub data_transfer: SerializedDataTransfer,
}Available on crate feature
prelude only.Expand description
A serialized version of DragData
Fields
mouse: SerializedPointInteractiondata_transfer: SerializedDataTransferTrait Implementations
Sourceimpl Clone for SerializedDragData
impl Clone for SerializedDragData
Sourcefn clone(&self) -> SerializedDragData
fn clone(&self) -> SerializedDragData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SerializedDragData
impl Debug for SerializedDragData
Sourceimpl<'de> Deserialize<'de> for SerializedDragData
impl<'de> Deserialize<'de> for SerializedDragData
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<SerializedDragData, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<SerializedDragData, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl HasDataTransferData for SerializedDragData
impl HasDataTransferData for SerializedDragData
fn data_transfer(&self) -> DataTransfer
Sourceimpl HasDragData for SerializedDragData
impl HasDragData for SerializedDragData
Sourceimpl HasFileData for SerializedDragData
impl HasFileData for SerializedDragData
Sourceimpl HasMouseData for SerializedDragData
impl HasMouseData for SerializedDragData
Sourceimpl InteractionElementOffset for SerializedDragData
impl InteractionElementOffset for SerializedDragData
Sourcefn element_coordinates(&self) -> Point2D<f64, ElementSpace>
fn element_coordinates(&self) -> Point2D<f64, ElementSpace>
Gets the coordinates of the event relative to the target element.
Sourcefn coordinates(&self) -> Coordinates
fn coordinates(&self) -> Coordinates
Gets the coordinates of the event.
Sourceimpl InteractionLocation for SerializedDragData
impl InteractionLocation for SerializedDragData
Sourcefn client_coordinates(&self) -> Point2D<f64, ClientSpace>
fn client_coordinates(&self) -> Point2D<f64, ClientSpace>
Gets the coordinates of the event relative to the browser viewport.
Sourcefn page_coordinates(&self) -> Point2D<f64, PageSpace>
fn page_coordinates(&self) -> Point2D<f64, PageSpace>
Gets the coordinates of the event relative to the page.
Sourcefn screen_coordinates(&self) -> Point2D<f64, ScreenSpace>
fn screen_coordinates(&self) -> Point2D<f64, ScreenSpace>
Gets the coordinates of the event relative to the screen.
Sourceimpl PartialEq for SerializedDragData
impl PartialEq for SerializedDragData
Sourceimpl PointerInteraction for SerializedDragData
impl PointerInteraction for SerializedDragData
Gets the buttons that are currently held down.
Gets the button that triggered the event.
Sourceimpl Serialize for SerializedDragData
impl Serialize for SerializedDragData
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for SerializedDragData