pub struct SerializedPointInteraction {}prelude and serialize only.Fields
alt_key: boolThe button number that was pressed (if applicable) when the mouse event was fired.
Indicates which buttons are pressed on the mouse (or other input device) when a mouse event is triggered.
Each button that can be pressed is represented by a given number (see below). If more than one button is pressed, the button values are added together to produce a new number. For example, if the secondary (2) and auxiliary (4) buttons are pressed simultaneously, the value is 6 (i.e., 2 + 4).
- 1: Primary button (usually the left button)
- 2: Secondary button (usually the right button)
- 4: Auxiliary button (usually the mouse wheel button or middle button)
- 8: 4th button (typically the “Browser Back” button)
- 16 : 5th button (typically the “Browser Forward” button)
client_x: f64The horizontal coordinate within the application’s viewport at which the event occurred (as opposed to the coordinate within the page).
For example, clicking on the left edge of the viewport will always result in a mouse event with a clientX value of 0, regardless of whether the page is scrolled horizontally.
client_y: f64The vertical coordinate within the application’s viewport at which the event occurred (as opposed to the coordinate within the page).
For example, clicking on the top edge of the viewport will always result in a mouse event with a clientY value of 0, regardless of whether the page is scrolled vertically.
ctrl_key: boolTrue if the control key was down when the mouse event was fired.
meta_key: boolTrue if the meta key was down when the mouse event was fired.
offset_x: f64The offset in the X coordinate of the mouse pointer between that event and the padding edge of the target node.
offset_y: f64The offset in the Y coordinate of the mouse pointer between that event and the padding edge of the target node.
page_x: f64The X (horizontal) coordinate (in pixels) of the mouse, relative to the left edge of the entire document. This includes any portion of the document not currently visible.
Being based on the edge of the document as it is, this property takes into account any horizontal scrolling of the page. For example, if the page is scrolled such that 200 pixels of the left side of the document are scrolled out of view, and the mouse is clicked 100 pixels inward from the left edge of the view, the value returned by pageX will be 300.
page_y: f64The Y (vertical) coordinate in pixels of the event relative to the whole document.
See page_x.
screen_x: f64The X coordinate of the mouse pointer in global (screen) coordinates.
screen_y: f64The Y coordinate of the mouse pointer in global (screen) coordinates.
shift_key: boolTrue if the shift key was down when the mouse event was fired.
Implementations
Sourceimpl SerializedPointInteraction
impl SerializedPointInteraction
pub fn new( trigger_button: Option<MouseButton>, held_buttons: EnumSet<MouseButton>, coordinates: Coordinates, modifiers: Modifiers, ) -> SerializedPointInteraction