pub struct TouchData { /* private fields */ }Available on crate feature
prelude only.Implementations
Sourceimpl TouchData
impl TouchData
Sourcepub fn new(inner: impl HasTouchData + 'static) -> TouchData
pub fn new(inner: impl HasTouchData + 'static) -> TouchData
Create a new TouchData
Sourcepub fn touches(&self) -> Vec<TouchPoint>
pub fn touches(&self) -> Vec<TouchPoint>
Get the pointers that are currently down
Sourcepub fn touches_changed(&self) -> Vec<TouchPoint>
pub fn touches_changed(&self) -> Vec<TouchPoint>
Get the touches that have changed since the last event
Sourcepub fn target_touches(&self) -> Vec<TouchPoint>
pub fn target_touches(&self) -> Vec<TouchPoint>
Get the touches that started and stayed on the element that triggered this event