CreateBoxedSignalStorage

Trait CreateBoxedSignalStorage 

pub trait CreateBoxedSignalStorage<T>: BoxedSignalStorage<<T as Readable>::Target> + 'static
where T: Readable + ?Sized,
{ }
Available on crate feature prelude only.
A trait for creating boxed readable and writable signals. This is implemented for UnsyncStorage and SyncStorage.

The storage type must implement CreateReadOnlySignalStorage<T> for every readable T type to be used with ReadSignal and WriteSignal.

You may need to add this trait as a bound when you call ReadSignal::new_maybe_sync or WriteSignal::new_maybe_sync while remaining generic over syncness.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> CreateBoxedSignalStorage<T> for SyncStorage
where T: Readable<Storage = SyncStorage> + Sync + Send + 'static + ?Sized,

Source

impl<T> CreateBoxedSignalStorage<T> for UnsyncStorage
where T: Readable<Storage = UnsyncStorage> + 'static + ?Sized,