pub struct DocumentConfig {Show 13 fields
pub viewport: Option<Viewport>,
pub base_url: Option<String>,
pub ua_stylesheets: Option<Vec<String>>,
pub net_provider: Option<Arc<dyn NetProvider>>,
pub navigation_provider: Option<Arc<dyn NavigationProvider>>,
pub shell_provider: Option<Arc<dyn ShellProvider>>,
pub html_parser_provider: Option<Arc<dyn HtmlParserProvider>>,
pub font_ctx: Option<FontContext>,
pub media_type: Option<MediaType>,
pub style_threading: StyleThreading,
pub incremental: Option<bool>,
pub abort_signal: Option<AbortSignal>,
pub subdocument_depth: usize,
}Expand description
Options used when constructing a BaseDocument
Fields
viewport: Option<Viewport>The initial Viewport
base_url: Option<String>The base url which relative URLs are resolved against
ua_stylesheets: Option<Vec<String>>User Agent stylesheets
net_provider: Option<Arc<dyn NetProvider>>Net provider to handle network requests for resources
Navigation provider to handle link clicks and form submissions
shell_provider: Option<Arc<dyn ShellProvider>>Shell provider to redraw requests, clipboard, etc
html_parser_provider: Option<Arc<dyn HtmlParserProvider>>HTML parser provider. Used to parse HTML for setInnerHTML
font_ctx: Option<FontContext>Parley FontContext
media_type: Option<MediaType>The CSS media type used to evaluate @media rules.
Defaults to MediaType::screen.
style_threading: StyleThreadingStrategy for Stylo’s style traversal.
Defaults to StyleThreading::Parallel.
incremental: Option<bool>Whether incremental layout is enabled. Defaults to true.
abort_signal: Option<AbortSignal>If set, every sub-resource Request blitz-dom creates for this
document will carry this signal. Aborting it cancels every in-flight
fetch tied to this document.
subdocument_depth: usizeHow deeply this document is nested within other documents
(0 for a root document). Used to limit <iframe> nesting depth.