pub struct NodeHandle { /* private fields */ }Implementations
Sourceimpl NodeHandle
impl NodeHandle
pub fn node_id(&self) -> usize
pub fn doc(&self) -> Ref<'_, BaseDocument>
Sourcepub fn try_doc(&self) -> Option<Ref<'_, BaseDocument>>
pub fn try_doc(&self) -> Option<Ref<'_, BaseDocument>>
Returns None if the document is currently mutably borrowed.
Use this from background tasks to avoid panicking during event handling.
pub fn doc_mut(&self) -> RefMut<'_, BaseDocument>
pub fn node(&self) -> Ref<'_, Node>
pub fn node_mut(&self) -> RefMut<'_, Node>