pub struct Action<I, T>where
T: 'static,{ /* private fields */ }prelude only.Expand description
A handle to an async action created by use_action.
Call it with .call(...) to dispatch work, read results with .value(),
and check progress with .pending(). Implements Copy so it can be moved
into multiple event handlers freely.
Implementations
Sourceimpl<I, O> Action<I, O>where
I: 'static,
O: 'static,
impl<I, O> Action<I, O>where
I: 'static,
O: 'static,
Sourcepub fn value(&self) -> Option<Result<ReadSignal<O>, CapturedError>>
pub fn value(&self) -> Option<Result<ReadSignal<O>, CapturedError>>
The result of the most recent call, if it has completed.
Returns None while the action is pending or has never been called.
Returns Some(Ok(signal)) on success or Some(Err(e)) on failure.
The returned ReadSignal is reactive — reading it in RSX will
subscribe the component to updates.
Sourceimpl<Out> Action<(), Out>
impl<Out> Action<(), Out>
Sourcepub fn call(&mut self) -> Dispatching<()> ⓘ
pub fn call(&mut self) -> Dispatching<()> ⓘ
Dispatch the action with no arguments.
Sourceimpl<A, Out> Action<(A,), Out>where
A: 'static,
impl<A, Out> Action<(A,), Out>where
A: 'static,
Sourcepub fn call(&mut self, A: A) -> Dispatching<()> ⓘ
pub fn call(&mut self, A: A) -> Dispatching<()> ⓘ
Dispatch the action with the given arguments.
Sourceimpl<A, B, Out> Action<(A, B), Out>where
A: 'static,
B: 'static,
impl<A, B, Out> Action<(A, B), Out>where
A: 'static,
B: 'static,
Sourcepub fn call(&mut self, A: A, B: B) -> Dispatching<()> ⓘ
pub fn call(&mut self, A: A, B: B) -> Dispatching<()> ⓘ
Dispatch the action with the given arguments.
Sourceimpl<A, B, C, Out> Action<(A, B, C), Out>where
A: 'static,
B: 'static,
C: 'static,
impl<A, B, C, Out> Action<(A, B, C), Out>where
A: 'static,
B: 'static,
C: 'static,
Sourcepub fn call(&mut self, A: A, B: B, C: C) -> Dispatching<()> ⓘ
pub fn call(&mut self, A: A, B: B, C: C) -> Dispatching<()> ⓘ
Dispatch the action with the given arguments.
Sourceimpl<A, B, C, D, Out> Action<(A, B, C, D), Out>where
A: 'static,
B: 'static,
C: 'static,
D: 'static,
impl<A, B, C, D, Out> Action<(A, B, C, D), Out>where
A: 'static,
B: 'static,
C: 'static,
D: 'static,
Sourcepub fn call(&mut self, A: A, B: B, C: C, D: D) -> Dispatching<()> ⓘ
pub fn call(&mut self, A: A, B: B, C: C, D: D) -> Dispatching<()> ⓘ
Dispatch the action with the given arguments.
Sourceimpl<A, B, C, D, E, Out> Action<(A, B, C, D, E), Out>where
A: 'static,
B: 'static,
C: 'static,
D: 'static,
E: 'static,
impl<A, B, C, D, E, Out> Action<(A, B, C, D, E), Out>where
A: 'static,
B: 'static,
C: 'static,
D: 'static,
E: 'static,
Sourcepub fn call(&mut self, A: A, B: B, C: C, D: D, E: E) -> Dispatching<()> ⓘ
pub fn call(&mut self, A: A, B: B, C: C, D: D, E: E) -> Dispatching<()> ⓘ
Dispatch the action with the given arguments.
Sourceimpl<A, B, C, D, E, F, Out> Action<(A, B, C, D, E, F), Out>where
A: 'static,
B: 'static,
C: 'static,
D: 'static,
E: 'static,
F: 'static,
impl<A, B, C, D, E, F, Out> Action<(A, B, C, D, E, F), Out>where
A: 'static,
B: 'static,
C: 'static,
D: 'static,
E: 'static,
F: 'static,
Sourcepub fn call(&mut self, A: A, B: B, C: C, D: D, E: E, F: F) -> Dispatching<()> ⓘ
pub fn call(&mut self, A: A, B: B, C: C, D: D, E: E, F: F) -> Dispatching<()> ⓘ
Dispatch the action with the given arguments.